==> pygitscrum-0.2.0-py3-none-any.whl: pygitscrum/args.py <==
import argparse
import sys


def compute_args():
    my_parser = argparse.ArgumentParser(
        description="pygitscrum : masterize git!!!",
        epilog="""
        Full documentation at: <https://github.com/thib1984/pygitscrum>.
        Report bugs to <https://github.com/thib1984/pygitscrum/issues>.
        MIT Licence.
        Copyright (c) 2021 thib1984.
        This is free software: you are free to change and redistribute it.
        There is NO WARRANTY, to the extent permitted by law.
        Written by thib1984.""",
    )
    my_parser.add_argument(
        "-v",
        "--debug",
        action="store_true",
        help="full trace",
    )
    my_group = my_parser.add_mutually_exclusive_group(required=True)
    my_group.add_argument(
        "-d",
        "--daily",
        metavar="since",
        action="store",
        type=str,
        nargs="?",
        const="yesterday",
        help="from scrum time, optionnal parameter : the 'since' in git format",
    )
    my_group.add_argument(
        "-s",
        "--search",
        metavar="keyword",
        action="store",
        type=str,
        help="search in the git logs the 'keyword'",
    )
    my_group.add_argument(
        "-c",
        "--check",
        action="store_true",
        help="check your repos one by one, fetch all, and ask you if a pull/push is available, you can also pull/push or check the differences",
    )
    my_group.add_argument(
        "-t",
        "--track",
        action="store_true",
        help="check your repos one by one, track new branches, delete inexisting branches at distant, and fetch all",
    )
    my_group.add_argument(
        "-V",
        "--version",
        action="store_true",
        help="display pygitscrum's version",
    )
    my_group.add_argument(
        "-u",
        "--update",
        action="store_true",
        help="update pygitscrum",
    )

    my_parser.add_argument(
        "to_path",
        metavar="to_path",
        type=str,
        nargs="?",
        default=".",
        help="the path to scan, defaut '.'",
    )

    # if no parameter
    if len(sys.argv) == 1:
        my_parser.print_help()
        exit(0)

    args = my_parser.parse_args()
    return args

==> pygitscrum-0.3.2-py3-none-any.whl: pygitscrum/args.py <==
"""
pygitscrum argparse gestion
"""

import argparse
import sys


def compute_args():
    """
    check args and return them
    """
    my_parser = argparse.ArgumentParser(
        description="pygitscrum : masterize git!!!",
        epilog="""
        Full documentation at: <https://github.com/thib1984/pygitscrum>.
        Report bugs to <https://github.com/thib1984/pygitscrum/issues>.
        MIT Licence.
        Copyright (c) 2021 thib1984.
        This is free software: you are free to change and redistribute it.
        There is NO WARRANTY, to the extent permitted by law.
        Written by thib1984.""",
    )
    my_parser.add_argument(
        "-v",
        "--debug",
        action="store_true",
        help="full trace",
    )
    my_parser.add_argument(
        "-f",
        "--fast",
        action="store_true",
        help="skip all questions, mute off output, except the summary",
    )
    my_group = my_parser.add_mutually_exclusive_group(required=True)
    my_group.add_argument(
        "-d",
        "--daily",
        metavar="git_period",
        action="store",
        type=str,
        nargs="?",
        const="yesterday",
        help="list your commits since <git_period> (default : yesterday) from all branches",
    )
    my_group.add_argument(
        "-s",
        "--search",
        metavar="keyword",
        action="store",
        type=str,
        help="search in logs 'keyword' from all",
    )
    my_group.add_argument(
        "-c",
        "--check",
        action="store_true",
        help="fetch all, check status, and ask you action if a pull/push is available",
    )
    my_group.add_argument(
        "-w",
        "--wip",
        action="store_true",
        help="fetch all, print stashs branches with push available, and number of untracked/unstagef/uncommited files",
    )
    my_group.add_argument(
        "-p",
        "--prune",
        action="store_true",
        help="fetch all, print stashs and gone local branch (inexisting in refs/remote)",
    )
    my_group.add_argument(
        "-t",
        "--track",
        action="store_true",
        help="fetch all, track new branches in remote repository, prune refs/remote if inexisting in remote repository",
    )
    my_group.add_argument(
        "-V",
        "--version",
        action="store_true",
        help="display pygitscrum's version",
    )
    my_group.add_argument(
        "-u",
        "--update",
        action="store_true",
        help="update pygitscrum",
    )

    my_parser.add_argument(
        "to_path",
        metavar="to_path",
        type=str,
        nargs="?",
        default=".",
        help="the path to scan, defaut '.'",
    )

    # if no parameter
    if len(sys.argv) == 1:
        my_parser.print_help()
        sys.exit(0)

    args = my_parser.parse_args()
    return args
